Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4661)

Unified Diff: chrome/browser/chromeos/network_message_observer.h

Issue 6347044: Only show notification for low 3g data for the last data-based plan.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 9 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/network_message_observer.h
===================================================================
--- chrome/browser/chromeos/network_message_observer.h (revision 74304)
+++ chrome/browser/chromeos/network_message_observer.h (working copy)
@@ -28,9 +28,15 @@
typedef std::map<std::string, WifiNetwork*> ServicePathWifiMap;
typedef std::map<std::string, CellularNetwork*> ServicePathCellularMap;
+ static bool IsApplicableBackupPlan(const CellularDataPlan* plan,
+ const CellularDataPlan* other_plan);
private:
virtual void OpenMobileSetupPage(const ListValue* args);
virtual void OpenMoreInfoPage(const ListValue* args);
+ virtual void HideDataNotifications();
+ virtual void InitNewPlan(const CellularDataPlan* plan);
+ virtual void ShowNoDataNotification(const CellularDataPlan* plan);
+ virtual void ShowLowDataNotification(const CellularDataPlan* plan);
// NetworkLibrary::NetworkManagerObserver implementation.
virtual void OnNetworkManagerChanged(NetworkLibrary* obj);
@@ -44,9 +50,8 @@
// Current connect celluar service path.
std::string cellular_service_path_;
- // Last cellular data plan name and type.
- std::string cellular_data_plan_name_;
- CellularDataPlanType cellular_data_plan_type_;
+ // Last cellular data plan unique id.
+ std::string cellular_data_plan_unique_id_;
// Notification for connection errors
SystemNotification notification_connection_error_;
« no previous file with comments | « chrome/browser/chromeos/cros/network_library.cc ('k') | chrome/browser/chromeos/network_message_observer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698